==> yybbs-0.54.zip: yybbs/include/MessageForm.php <==
<?php
/**
@brief åơԽե
@version $Id: MessageForm.php,v 1.6 2004/08/02 03:14:49 minahito Exp $
*/

require_once "exForm/Form.php";
require_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";
require_once XOOPS_ROOT_PATH."/modules/yybbs/class/user.php";

class MessageForm extends exAbstractActionForm {
	var $bbs_;
	var $cookieUser_;

	/**
	@brief GET ꥯȤϤʤΤǡȤߤʤ
	*/
	function doGet($data) {
		$this->msg_[]="ʥꥯȤǤ";
	}
	
	/**
	@brief 
	*/
	function doPost($data) {
		global $xoopsModule;
		global $xoopsUser;
		
		require_once XOOPS_ROOT_PATH."/modules/".$xoopsModule->dirname()."/class/user.php";

		// 󥹥󥹤κ
		$handler=&YYBBS::getHandler('message');
		$id=$this->getPositive($_POST['id']);
		if($id>0){
			$this->data_=&$handler->get($id);
			if(!is_object($this->data_)) {
				$this->msg_[]="׵Ǥ";
				return;
			}
		}
		else {
			$this->data_=&$handler->create();

			// inputdate 񤭹ޤΤ Τ
			$this->data_->setVar('inputdate',time());
			$this->data_->setVar('update_date',time());

			//uid
			$bbsUser=new YYBBSUser($xoopsUser);
			$this->data_->setVar('uid',$bbsUser->getVar('uid'));
		}

		// BBS ¸ߤ뤫
		$bbs_id=$this->getPositive($_POST['bbs_id']);
		if(!$bbs_id) {
			$this->msg_[]="׵Ǥ";
			return;
		}
		$bHandler=&YYBBS::getHandler('bbs');
		$this->bbs_ =& $bHandler->get($bbs_id);
		if(!is_object($this->bbs_)) {
			$this->msg_[]="񤭹ߤԤȤ BBS ¸ߤޤ";
			return;
		}

		$this->data_->setVar('bbs_id',$this->bbs_->getVar('bbs_id'));

		// ʤ serial 
		if($this->data_->isNew())
			$this->data_->setVar('serial',$this->bbs_->getVar('serial'));
		
		// cleanVars Ǥ
		if(!strlen($_POST['name']))
			$this->msg_[] = _MD_YYBBS_ERRMES_NAME;
		$this->data_->setVar('name',$_POST['name']);

		if(!strlen($_POST['title']))
			$this->msg_[] = _MD_YYBBS_ERRMES_TITLE;
		$this->data_->setVar('title',$_POST['title']);

		if(!strlen($_POST['message']))
			$this->msg_[] = _MD_YYBBS_ERRMES_MESSAGE;
		$this->data_->setVar('message',$_POST['message']);

		$this->data_->setVar('email',$_POST['email']);
		$this->data_->setVar('icon',$_POST['icon']);
		$this->data_->setVar('col',$_POST['col']);

		if(!$this->validateMaxLength($_POST['passwd'],8)) {
			$this->msg_[]="ѥɤĹޤ";
		}

		$this->data_->setVar('passwd',md5($_POST['passwd']));

		if(!strlen(trim($_POST['url'])))
			$this->data_->setVar('url','http://');
		elseif(!$this->validateHttpUrl($_POST['url']))
			$this->msg_[]="URL Ǥ";
		else
			$this->data_->setVar('url',trim($_POST['url']));

		// parent 񤭹¸ߤǧ뤳
		$parent_id=$this->getPositive($_POST['parent']);
		if($parent_id>0) {
    		$parent=&$handler->get($parent_id);
    		if(!is_object($parent)) {	// ƥåʤ
    			$this->msg_[]="ֿå¸ߤޤʥǤ";
    		}
    		else {	// parent οƤФϿ
    			$this->data_->setVar('parent',
    				$parent->getVar('parent') ? $parent->getVar('parent') : $parent_id);
    		}
		}

		$this->data_->setVar('ip',$_SERVER['REMOTE_ADDR']);

		// cookie
		$this->cookieUser_=new YYBBSCookieUser();
		$this->cookieUser_->fetch();

		// ޤǤǥ顼нʣΤΤ cleanVars ʤ
		if(!count($this->msg_)) {
    		if(!$this->data_->cleanVars()) {
    			$this->msg_=array_merge($this->msg_,$this->data_->getErrors());
    		}
		}
	}
}

?>

==> yybbs-0.57.zip: yybbs/include/MessageForm.php <==
<?php
/**
@brief åơԽե
@version $Id: MessageForm.php,v 1.8 2004/08/04 16:35:58 minahito Exp $
*/

require_once "exForm/Form.php";
require_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";
require_once XOOPS_ROOT_PATH."/modules/yybbs/class/user.php";

class MessageForm extends exAbstractActionForm {
	var $bbs_;
	var $cookieUser_;

	/**
	@brief GET ꥯȤϤʤΤǡȤߤʤ
	*/
	function doGet($data) {
		$this->msg_[]="ʥꥯȤǤ";
	}
	
	/**
	@brief 
	*/
	function doPost($data) {
		global $xoopsModule;
		global $xoopsUser;
		global $xoopsModuleConfig;
		
		require_once XOOPS_ROOT_PATH."/modules/".$xoopsModule->dirname()."/class/user.php";

		// 󥹥󥹤κ
		$handler=&YYBBS::getHandler('message');
		$id=$this->getPositive($_POST['id']);
		if($id>0){
			$this->data_=&$handler->get($id);
			if(!is_object($this->data_)) {
				$this->msg_[]="׵Ǥ";
				return;
			}
		}
		else {
			$this->data_=&$handler->create();

			// inputdate 񤭹ޤΤ Τ
			$this->data_->setVar('inputdate',time());
			$this->data_->setVar('update_date',time());

			//uid
			$bbsUser=new YYBBSUser($xoopsUser);
			$this->data_->setVar('uid',$bbsUser->getVar('uid'));
		}

		// BBS ¸ߤ뤫
		$bbs_id=$this->getPositive($_POST['bbs_id']);
		if(!$bbs_id) {
			$this->msg_[]="׵Ǥ";
			return;
		}
		$bHandler=&YYBBS::getHandler('bbs');
		$this->bbs_ =& $bHandler->get($bbs_id);
		if(!is_object($this->bbs_)) {
			$this->msg_[]="񤭹ߤԤȤ BBS ¸ߤޤ";
			return;
		}

		$this->data_->setVar('bbs_id',$this->bbs_->getVar('bbs_id'));

		// ʤ serial 
		if($this->data_->isNew())
			$this->data_->setVar('serial',$this->bbs_->getVar('serial'));
		
		// cleanVars Ǥ
		if(!strlen($_POST['name']))
			$this->msg_[] = _MD_YYBBS_ERRMES_NAME;
		$this->data_->setVar('name',$_POST['name']);

		if(!strlen($_POST['title']))
			$this->msg_[] = _MD_YYBBS_ERRMES_TITLE;
		$this->data_->setVar('title',$_POST['title']);

		if(!strlen($_POST['message']))
			$this->msg_[] = _MD_YYBBS_ERRMES_MESSAGE;
		$this->data_->setVar('message',$_POST['message']);

		$this->data_->setVar('email',$_POST['email']);
		$this->data_->setVar('icon',$_POST['icon']);
		$this->data_->setVar('col',$_POST['col']);

		if(!$this->validateMaxLength($_POST['passwd'],8)) {
			$this->msg_[]="ѥɤĹޤ";
		}

		$this->data_->setVar('passwd',md5($_POST['passwd']));

		if(!strlen(trim($_POST['url'])))
			$this->data_->setVar('url','http://');
		elseif(!$this->validateHttpUrl($_POST['url']))
			$this->msg_[]="URL Ǥ";
		else
			$this->data_->setVar('url',trim($_POST['url']));

		// parent 񤭹¸ߤǧ뤳
		$parent_id=$this->getPositive($_POST['parent']);
		if($parent_id>0) {
    		$parent=&$handler->get($parent_id);
    		if(!is_object($parent)) {	// ƥåʤ
    			$this->msg_[]="ֿå¸ߤޤʥǤ";
    		}
    		else {	// parent οƤФϿ
    			$this->data_->setVar('parent',
    				$parent->getVar('parent') ? $parent->getVar('parent') : $parent_id);
    		}
		}
		else { // post ʤ鸢¤ǧ
        	if($xoopsModuleConfig['permission']){
        		if(!exPerm::Guard_global("post_new_thread",$this->bbs_->getVar('bbs_id'))) {
        			$this->msg_[]=_MD_YYBBS_ERRMES_PERM;
        		}
        	}
		}

		$this->data_->setVar('ip',$_SERVER['REMOTE_ADDR']);

		// cookie
		$this->cookieUser_=new YYBBSCookieUser();
		$this->cookieUser_->fetch();

		// ޤǤǥ顼нʣΤΤ cleanVars ʤ
		if(!count($this->msg_)) {
    		if(!$this->data_->cleanVars()) {
    			$this->msg_=array_merge($this->msg_,$this->data_->getErrors());
    		}
		}
	}
}

?>
